@@ -1,10 +1,15 @@
-"""Common code for Airzone library."""
+"""Airzone library common code."""
 from __future__ import annotations
 
 from dataclasses import dataclass
 from enum import Enum
 
 
+def system_zone_id(system_id: int, zone_id: int) -> str:
+    """Combine System and Zone IDs into a single ID."""
+    return f"{system_id}:{zone_id}"
+
+
 class AirzoneStages(int, Enum):
     """Airzone stages."""
 
@@ -13,14 +18,6 @@ class AirzoneStages(int, Enum):
     Combined = 3
 
 
-class AirzoneType(int, Enum):
-    """Airzone operation modes."""
-
-    A = 1
-    B = 2
-    C = 3
-
-
 @dataclass
 class ConnectionOptions:
     """Airzone options for connection."""
