@@ -1,4 +1,4 @@
-"""Constants for aioairzone."""
+"""Airzone library constants."""
 
 API_ACS_POINT = "acs_temp"
 API_AIR_DEMAND = "air_demand"
@@ -49,6 +49,7 @@ AZD_HEAT_STAGE = "heat_stage"
 AZD_HEAT_STAGES = "heat_stages"
 AZD_HUMIDITY = "humidity"
 AZD_ID = "id"
+AZD_MASTER = "master"
 AZD_MODE = "mode"
 AZD_MODES = "modes"
 AZD_NAME = "name"
@@ -62,7 +63,6 @@ AZD_TEMP_MAX = "temp_max"
 AZD_TEMP_MIN = "temp_min"
 AZD_TEMP_SET = "temp_set"
 AZD_TEMP_UNIT = "temp_unit"
-AZD_TYPE = "type"
 AZD_ZONES = "zones"
 AZD_ZONES_NUM = "num_zones"
 
