@@ -1,27 +1,24 @@
 """Airzone Local API based device."""
 from __future__ import annotations
 
-import asyncio
 import json
 import logging
 from typing import Any, cast
 
-import aiohttp
+from aiohttp import ClientSession
 from aiohttp.client_reqrep import ClientResponse
 
 from .common import (
     AirzoneStages,
-    AirzoneType,
     ConnectionOptions,
     OperationMode,
     TemperatureUnit,
+    system_zone_id,
 )
 from .const import (
-    API_ACS_POINT,
     API_AIR_DEMAND,
     API_COLD_STAGE,
     API_COLD_STAGES,
-    API_COOL_SET_POINT,
     API_DATA,
     API_ERROR_SYSTEM_ID_OUT_RANGE,
     API_ERROR_ZONE_ID_NOT_AVAILABLE,
@@ -57,6 +54,7 @@ from .const import (
     AZD_HEAT_STAGES,
     AZD_HUMIDITY,
     AZD_ID,
+    AZD_MASTER,
     AZD_MODE,
     AZD_MODES,
     AZD_NAME,
@@ -70,7 +68,6 @@ from .const import (
     AZD_TEMP_MIN,
     AZD_TEMP_SET,
     AZD_TEMP_UNIT,
-    AZD_TYPE,
     AZD_ZONES,
     AZD_ZONES_NUM,
     HTTP_CALL_TIMEOUT,
@@ -92,16 +89,13 @@ class AirzoneLocalApi:
 
     def __init__(
         self,
-        aiohttp_session: aiohttp.ClientSession,
+        aiohttp_session: ClientSession,
         options: ConnectionOptions,
     ):
         """Device init."""
-        self.aiohttp_session: aiohttp.ClientSession = aiohttp_session
-        self.options: ConnectionOptions = options
-        self.connect_task = None
-        self.connect_result = None
+        self.aiohttp_session = aiohttp_session
+        self.options = options
         self.systems: dict[int, System] = {}
-        self._loop = asyncio.get_running_loop()
 
     @property
     def ip_address(self) -> str:
@@ -129,7 +123,7 @@ class AirzoneLocalApi:
         _LOGGER.debug("aiohttp response: %s", resp_json)
         return cast(dict, resp_json)
 
-    async def validate_airzone(self):
+    async def validate_airzone(self) -> None:
         """Gather Airzone systems."""
         response = await self.get_hvac()
         if API_SYSTEMS not in response:
@@ -137,11 +131,11 @@ class AirzoneLocalApi:
 
     async def update_airzone(self) -> bool:
         """Gather Airzone systems."""
-        systems = {}
+        systems: dict[int, System] = {}
 
         airzone_systems = await self.get_hvac()
         for airzone_system in airzone_systems[API_SYSTEMS]:
-            system = System(self, airzone_system[API_DATA])
+            system = System(airzone_system[API_DATA])
             if system:
                 systems[system.get_id()] = system
 
@@ -194,8 +188,8 @@ class AirzoneLocalApi:
                     raise InvalidParam
                 raise ParamUpdateFailure
 
-        system: System = self.get_system(data[API_SYSTEM_ID])
-        zone: Zone = self.get_zone(data[API_SYSTEM_ID], data[API_ZONE_ID])
+        system = self.get_system(data[API_SYSTEM_ID])
+        zone = self.get_zone(data[API_SYSTEM_ID], data[API_ZONE_ID])
         for key, value in data.items():
             if key in API_SYSTEM_PARAMS:
                 system.set_param(key, value)
@@ -217,48 +211,41 @@ class AirzoneLocalApi:
             for system_id, system in self.systems.items():
                 systems[system_id] = system.data()
                 for zone_id, zone in system.zones.items():
-                    zones[f"{system_id}:{zone_id}"] = zone.data()
+                    zones[system_zone_id(system_id, zone_id)] = zone.data()
             data[AZD_SYSTEMS] = systems
             data[AZD_ZONES] = zones
 
         return data
 
-    def get_system(self, system_id) -> System:
+    def get_system(self, system_id: int) -> System:
         """Return Airzone system."""
-        system: System
         for system in self.systems.values():
             if system.get_id() == system_id:
                 return system
         raise InvalidSystem
 
-    def get_zone(self, system_id, zone_id) -> Zone:
+    def get_zone(self, system_id: int, zone_id: int) -> Zone:
         """Return Airzone system zone."""
         return self.get_system(system_id).get_zone(zone_id)
 
     def num_systems(self) -> int:
         """Return number of airzone systems."""
-        if self.systems:
-            return len(self.systems)
-        return 0
+        return len(self.systems)
 
     def num_zones(self) -> int:
         """Return total number of zones."""
         count = 0
-        if self.systems:
-            for system in self.systems.values():
-                count += system.num_zones()
+        for system in self.systems.values():
+            count += system.num_zones()
         return count
 
 
 class System:
     """Airzone System."""
 
-    def __init__(self, airzone, airzone_system):
+    def __init__(self, airzone_system):
         """System init."""
-        self.airzone = airzone
         self.id = None
-        self.master_zone = None
-        self.type = None
         self.zones: dict[int, Zone] = {}
 
         for airzone_zone in airzone_system:
@@ -272,28 +259,15 @@ class System:
 
                 self.zones[zone.get_id()] = zone
 
-                if zone.is_master():
-                    self.master_zone = zone
-
-                    if API_COOL_SET_POINT in airzone_zone:
-                        self.type = AirzoneType.B
-                    elif API_ACS_POINT in airzone_zone:
-                        self.type = AirzoneType.A
-                    else:
-                        self.type = AirzoneType.C
-
-    def data(self):
+    def data(self) -> dict[str, Any]:
         """Return Airzone system data."""
-        data = {
+        data: dict[str, Any] = {
             AZD_ID: self.get_id(),
             AZD_ZONES_NUM: self.num_zones(),
         }
 
-        if self.type:
-            data[AZD_TYPE] = self.get_type()
-
         if self.zones:
-            zones = {}
+            zones: dict[int, Any] = {}
             for _id, zone in self.zones.items():
                 zones[_id] = zone.data()
             data[AZD_ZONES] = zones
@@ -304,17 +278,8 @@ class System:
         """Return system ID."""
         return self.id
 
-    def get_master_zone(self) -> Zone:
-        """Return Airzone master zone."""
-        return self.master_zone
-
-    def get_type(self) -> AirzoneType:
-        """Return system type."""
-        return self.type
-
-    def get_zone(self, zone_id) -> Zone:
+    def get_zone(self, zone_id: int) -> Zone:
         """Return Airzone zone."""
-        zone: Zone
         for zone in self.zones.values():
             if zone.get_id() == zone_id:
                 return zone
@@ -333,16 +298,19 @@ class System:
 class Zone:
     """Airzone Zone."""
 
-    def __init__(self, system: System, zone):
+    def __init__(self, system: System, zone: dict[str, Any]):
         """Zone init."""
         self.air_demand = bool(zone[API_AIR_DEMAND])
         self.cold_stage = AirzoneStages(zone[API_COLD_STAGE])
+        self.cold_stages: list[AirzoneStages] = []
         self.floor_demand = bool(zone[API_FLOOR_DEMAND])
         self.heat_stage = AirzoneStages(zone[API_HEAT_STAGE])
+        self.heat_stages: list[AirzoneStages] = []
         self.humidity = int(zone[API_HUMIDITY])
         self.id = int(zone[API_ZONE_ID])
-        self.master = None
+        self.master = bool(API_MODES in zone)
         self.mode = OperationMode(zone[API_MODE])
+        self.modes: list[OperationMode] = []
         self.name = str(zone[API_NAME])
         self.on = bool(zone[API_ON])
         self.temp = float(zone[API_ROOM_TEMP])
@@ -354,14 +322,8 @@ class Zone:
 
         if API_COLD_STAGES in zone:
             if isinstance(zone[API_COLD_STAGES], list):
-                stages = []
                 for stage in zone[API_COLD_STAGES]:
-                    stages.append(AirzoneStages(stage))
-                self.cold_stages = stages
-            else:
-                self.cold_stages = []
-        else:
-            self.cold_stages = []
+                    self.cold_stages.append(AirzoneStages(stage))
 
         if len(zone[API_ERRORS]):
             self.errors = zone[API_ERRORS]
@@ -370,24 +332,18 @@ class Zone:
 
         if API_HEAT_STAGES in zone:
             if isinstance(zone[API_HEAT_STAGES], list):
-                stages = []
                 for stage in zone[API_HEAT_STAGES]:
-                    stages.append(AirzoneStages(stage))
-                self.heat_stages = stages
-            else:
-                self.heat_stages = []
-        else:
-            self.heat_stages = []
+                    self.heat_stages.append(AirzoneStages(stage))
 
-        if API_MODES in zone:
-            modes = []
+        if self.master:
             for mode in zone[API_MODES]:
-                modes.append(OperationMode(mode))
-            self.modes = modes
+                self.modes.append(OperationMode(mode))
         else:
-            self.modes = []
+            self.modes.append(self.mode)
+        if OperationMode.STOP not in self.modes:
+            self.modes.append(OperationMode.STOP)
 
-    def data(self):
+    def data(self) -> dict[str, Any]:
         """Return Airzone zone data."""
         data = {
             AZD_AIR_DEMAND: self.get_air_demand(),
@@ -397,6 +353,7 @@ class Zone:
             AZD_HEAT_STAGE: self.get_heat_stage(),
             AZD_HUMIDITY: self.get_humidity(),
             AZD_ID: self.get_id(),
+            AZD_MASTER: self.get_master(),
             AZD_MODE: self.get_mode(),
             AZD_NAME: self.get_name(),
             AZD_ON: self.get_on(),
@@ -463,6 +420,10 @@ class Zone:
         """Return zone humidity."""
         return self.humidity
 
+    def get_master(self) -> bool:
+        """Return zone master/slave."""
+        return self.master
+
     def get_mode(self) -> OperationMode:
         """Return zone mode."""
         return self.mode
@@ -507,21 +468,17 @@ class Zone:
         """Return zone temperature unit."""
         return self.temp_unit
 
-    def is_master(self) -> bool:
-        """Zone is master if mode can be changed."""
-        return self.modes is not None
-
     def set_param(self, key: str, value: Any) -> None:
         """Update zone parameter by key and value."""
         if key == API_COLD_STAGE:
-            self.cold_stage = value
+            self.cold_stage = AirzoneStages(value)
         elif key == API_HEAT_STAGE:
-            self.heat_stage = value
+            self.heat_stage = AirzoneStages(value)
         elif key == API_MODE:
-            self.mode = value
+            self.mode = OperationMode(value)
         elif key == API_NAME:
-            self.name = value
+            self.name = str(value)
         elif key == API_ON:
-            self.on = value
+            self.on = bool(value)
         elif key == API_SET_POINT:
-            self.temp_set = value
+            self.temp_set = float(value)
